/***************************************************************************
                          dcobject.h  -  description
                             -------------------
    begin                : Fri Feb 22 2002
    copyright            : (C) 2002-2003 by Mathias Kster
    email                : mathen@ketelhot.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _DCOBJECT_H_
#define _DCOBJECT_H_

/**
  *@author Mathias Kster
  */

#include <time.h>

#include <dclib/dcos.h>
#include <dclib/cobject.h>
#include <dclib/cstring.h>
#include <dclib/clist.h>

#define DC_USER_FILELIST_HE3 	"MyList.DcLst"
#define DC_USER_FILELIST 	DC_USER_FILELIST_HE3
#define DC_USER_FILELIST_BZ 	"MyList.bz2"

typedef enum eDCMessage {
	DC_MESSAGE_PARSE_ERROR=0,

	DC_MESSAGE_CONNECTION_STATE,	// internal con. state
	DC_MESSAGE_TRANSFER,		// transfer state

	DC_MESSAGE_UNKNOWN,

	// direct connect proto
	DC_MESSAGE_LOCK,
	DC_MESSAGE_HELLO,
	DC_MESSAGE_HUBNAME,
	DC_MESSAGE_CHAT,
	DC_MESSAGE_MYINFO,
	DC_MESSAGE_QUIT,
	DC_MESSAGE_NICKLIST,		// 10
	DC_MESSAGE_OPLIST,
	DC_MESSAGE_CONNECTTOME,
	DC_MESSAGE_KEY,
	DC_MESSAGE_PRIVATECHAT,
	DC_MESSAGE_SEARCH,
	DC_MESSAGE_REVCONNECTTOME,
	DC_MESSAGE_SEARCHRESULT,
	DC_MESSAGE_FORCEMOVE,
	DC_MESSAGE_MYNICK,		// connect to me
	DC_MESSAGE_DIRECTION,		// 20 connect to me
	DC_MESSAGE_MAXEDOUT,
	DC_MESSAGE_FILELENGTH,
	DC_MESSAGE_ERROR,		// file not found ...
	DC_MESSAGE_GET,
	DC_MESSAGE_GETLISTLEN,
	DC_MESSAGE_VALIDATEDENIDE,
	DC_MESSAGE_GETINFO,
	DC_MESSAGE_AGE,
	DC_MESSAGE_HUBISFULL,
	DC_MESSAGE_LISTLEN,		// 30
	DC_MESSAGE_SEND,
	DC_MESSAGE_PING,
	DC_MESSAGE_GETPASS,		// user need a password
	DC_MESSAGE_BADPASS,		// wrong password
	DC_MESSAGE_LOGEDIN,		// admin
	DC_MESSAGE_CANCEL,		// cancel a transfer
	DC_MESSAGE_CANCELED,		// the transfer is canceled
	DC_MESSAGE_SUPPORTS,

	// download manager types
	DC_MESSAGE_FILE_OBJECT,
	DC_MESSAGE_TRANSFER_OBJECT,
	DC_MESSAGE_FILELIST_OBJECT,
	DC_MESSAGE_SLOT_OBJECT,
	DC_MESSAGE_LOG,
	DC_MESSAGE_DM_INFO,

	// search manager types
	DC_MESSAGE_SEARCH_FILE,
	DC_MESSAGE_SEARCH_USER,
	DC_MESSAGE_SEARCHRESULT_USER,

	// file manager
	DC_MESSAGE_FM_INFO,

	// traffic control
	DC_MESSAGE_TRAFFIC
};

/** transfer medium */
typedef enum eltMedium {
	eltNONE=0,
	eltBUFFER,
	eltFILE
};

/** direction */
typedef enum eDirection {
	edNONE=0,
	edUPLOAD,
	edDOWNLOAD
};

/** socket state */
typedef enum eConnectionState {
	estNONE=0,
	estCONNECT,
	estCONNECTING,
	estCONNECTED,
	estDISCONNECTING,
	estDISCONNECTED,
	estSOCKETERROR,
	estCONNECTIONTIMEOUT,
	estTRANSFERHANDSHAKE,
	estTRANSFERDOWNLOAD,
	estTRANSFERUPLOAD
};

typedef enum eTransferFileState {
	etfsNONE=0,
	etfsTRANSFER,
	etfsERROR
};

typedef enum eTransferWaitState {
	etwsWAIT=0,
	etwsIDLE,
	etwsRUN,
	etwsPAUSE,
	etwsHUBOFFLINE,
	etwsUSEROFFLINE,
	etwsUSERBUSY,
	etwsSENDERROR
};

typedef enum eClientMode {
	ecmNone=0,
	ecmActive,
	ecmPassive
};

typedef enum eUserAwayMode {
	euamNONE,
	euamNORMAL,
	euamAWAY
};

typedef enum eFileTypes {
	eftUNKNOWN=0,
	eftALL,
	eftMP3,
	eftARCHIVE,
	eftDOCUMENT,
	eftAPPLICATION,
	eftPICTURE,
	eftVIDEO,
	eftFOLDER
};

typedef enum eUserClientVersion {
	eucvNONE,
	eucvDCPP,
	eucvDCGUI
};

class DLL_EXPORT CDCMessage : public CObject {
public:
	/** */
	CDCMessage( eDCMessage type = DC_MESSAGE_UNKNOWN ) {
		m_eType = type;
	};
	/** */
	virtual ~CDCMessage() {};

	/** */
	eDCMessage m_eType;
};

class DLL_EXPORT CMessagePing : public CDCMessage {
public:
	/** */
	CMessagePing() : CDCMessage(DC_MESSAGE_PING) {};
	/** */
	virtual ~CMessagePing() {};
};

class DLL_EXPORT CMessageGetInfo : public CDCMessage {
public:
	/** */
	CMessageGetInfo() : CDCMessage(DC_MESSAGE_GETINFO) {};
	/** */
	virtual ~CMessageGetInfo() {};

	/** */
	CString sNick;
	/** */
	CString sFrom;
};

class DLL_EXPORT CMessageConnectionState : public CDCMessage {
public:
	/** */
	CMessageConnectionState() : CDCMessage(DC_MESSAGE_CONNECTION_STATE) {
		eState = estNONE;
	};
	/** */
	virtual ~CMessageConnectionState() {};

	/** */
	eConnectionState eState;
	/** */
	CString sMessage;
};

class DLL_EXPORT CMessageTransfer : public CDCMessage {
public:
	/** */
	CMessageTransfer() : CDCMessage(DC_MESSAGE_TRANSFER) {
		iMode       = 0;
		lTransfered = 0;
		lLength     = 0;
	};
	/** */
	virtual ~CMessageTransfer() {};

	/** */
	int iMode;		/* 0: send 1:recv */
	/** */
	ulonglong lTransfered;
	/** */
	ulonglong lLength;
};

class DLL_EXPORT CMessageSupports : public CDCMessage {
public:
	/** */
	CMessageSupports() : CDCMessage(DC_MESSAGE_SUPPORTS) {
		bBZList = FALSE;
		bSSL    = FALSE;
		bChunk  = FALSE;
	};
	/** */
	virtual ~CMessageSupports() {};
	/** */
	CMessageSupports& operator = (const CMessageSupports& s)
	{
		bBZList = s.bBZList;
		bSSL    = s.bSSL;
		bChunk  = s.bChunk;
		return *this;
	};

	/** */
	bool bBZList;
	/** */
	bool bSSL;
	/** */
	bool bChunk;
};

class DLL_EXPORT CMessageError : public CDCMessage {
public:
	/** */
	CMessageError() : CDCMessage(DC_MESSAGE_ERROR) {};
	/** */
	virtual ~CMessageError() {};

	/** */
	CString sError;
};

class DLL_EXPORT CMessageGet : public CDCMessage {
public:
	/** */
	CMessageGet() : CDCMessage(DC_MESSAGE_GET) {
		lPos  = 0;
		lSize = 0;
	};
	/** */
	virtual ~CMessageGet() {};

	/** */
	CString sFilename;
	/** */
	ulonglong lPos;
	/** */
	ulonglong lSize;
};

class DLL_EXPORT CMessageGetPass : public CDCMessage {
public:
	/** */
	CMessageGetPass() : CDCMessage(DC_MESSAGE_GETPASS) {};
	/** */
	virtual ~CMessageGetPass() {};
};

class DLL_EXPORT CMessageCancel : public CDCMessage {
public:
	/** */
	CMessageCancel() : CDCMessage(DC_MESSAGE_CANCEL) {};
	/** */
	virtual ~CMessageCancel() {};
};

class DLL_EXPORT CMessageCanceled : public CDCMessage {
public:
	/** */
	CMessageCanceled() : CDCMessage(DC_MESSAGE_CANCELED) {};
	/** */
	virtual ~CMessageCanceled() {};
};

class DLL_EXPORT CMessageKey : public CDCMessage {
public:
	/** */
	CMessageKey() : CDCMessage(DC_MESSAGE_KEY) {};
	/** */
	virtual ~CMessageKey() {};
};

class DLL_EXPORT CMessageBadPass : public CDCMessage {
public:
	/** */
	CMessageBadPass() : CDCMessage(DC_MESSAGE_BADPASS) {};
	/** */
	virtual ~CMessageBadPass() {};
};

class DLL_EXPORT CMessageLogedIn : public CDCMessage {
public:
	/** */
	CMessageLogedIn() : CDCMessage(DC_MESSAGE_LOGEDIN) {};
	/** */
	virtual ~CMessageLogedIn() {};

	/** */
	CString sNick;
};

class DLL_EXPORT CMessageSend : public CDCMessage {
public:
	/** */
	CMessageSend() : CDCMessage(DC_MESSAGE_SEND) {};
	/** */
	virtual ~CMessageSend() {};
};

class DLL_EXPORT CMessageValidateDenide : public CDCMessage {
public:
	/** */
	CMessageValidateDenide() : CDCMessage(DC_MESSAGE_VALIDATEDENIDE) {};
	/** */
	virtual ~CMessageValidateDenide() {};
};

class DLL_EXPORT CMessageHubIsFull : public CDCMessage {
public:
	/** */
	CMessageHubIsFull() : CDCMessage(DC_MESSAGE_HUBISFULL) {};
	/** */
	virtual ~CMessageHubIsFull() {};
};

class DLL_EXPORT CMessageMaxedOut : public CDCMessage {
public:
	/** */
	CMessageMaxedOut() : CDCMessage(DC_MESSAGE_MAXEDOUT) {};
	/** */
	virtual ~CMessageMaxedOut() {};
};

class DLL_EXPORT CMessageGetListLen : public CDCMessage {
public:
	/** */
	CMessageGetListLen() : CDCMessage(DC_MESSAGE_GETLISTLEN) {};
	/** */
	virtual ~CMessageGetListLen() {};
};

class DLL_EXPORT CMessageLock : public CDCMessage {
public:
	/** */
	CMessageLock() : CDCMessage(DC_MESSAGE_LOCK) {
		eClientVersion = eucvNONE;
		bExtProtocol   = FALSE;
		nVersionMajor  = 0;
		nVersionMinor  = 0;
		nVersionPatch  = 0;
	};
	/** */
	virtual ~CMessageLock() {};

	/** */
	CString sPK;
	/** */
	CString sData;
	/** */
	eUserClientVersion eClientVersion;
	/** */
	CString sVersionString;
	/** */
	int nVersionMajor;
	/** */
	int nVersionMinor;
	/** */
	int nVersionPatch;
	/** */
	bool bExtProtocol;
};

class DLL_EXPORT CMessageFileLength : public CDCMessage {
public:
	/** */
	CMessageFileLength() : CDCMessage(DC_MESSAGE_FILELENGTH) {
		lFileLength = 0;
	};
	/** */
	virtual ~CMessageFileLength() {};

	/** */
	ulonglong lFileLength;
};

class DLL_EXPORT CMessageDirection : public CDCMessage {
public:
	/** */
	CMessageDirection() : CDCMessage(DC_MESSAGE_DIRECTION) {
		iLevel    = 0;
		Direction = edNONE;
	};
	/** */
	virtual ~CMessageDirection() {};

	/** */
	eDirection Direction;
	/** */
	int iLevel;
};

#ifdef WIN32
template class DLL_EXPORT CList<CString>;
#endif

class DLL_EXPORT CMessageNickList : public CDCMessage {
public:
	/** */
	CMessageNickList() : CDCMessage(DC_MESSAGE_NICKLIST) {};
	/** */
	virtual ~CMessageNickList() {};

	/** */
	CList<CString> NickList;
};

class DLL_EXPORT CMessageNick : public CDCMessage {
public:
	/** */
	CMessageNick() {};
	/** */
	virtual ~CMessageNick() {};

	/** */
	CString sNick;
};

class DLL_EXPORT CMessageMyNick : public CDCMessage {
public:
	/** */
	CMessageMyNick() : CDCMessage(DC_MESSAGE_MYNICK) {};
	/** */
	virtual ~CMessageMyNick() {};

	/** */
	CString sMyNick;
};

class DLL_EXPORT CMessageHello : public CDCMessage {
public:
	/** */
	CMessageHello() : CDCMessage(DC_MESSAGE_HELLO) {};
	/** */
	virtual ~CMessageHello() {};

	/** */
	CString sNick;
};

class DLL_EXPORT CMessageQuit : public CDCMessage {
public:
	/** */
	CMessageQuit() : CDCMessage(DC_MESSAGE_QUIT) {};
	/** */
	virtual ~CMessageQuit() {};

	/** */
	CString sNick;
};

class DLL_EXPORT CMessageChat : public CDCMessage {
public:
	/** */
	CMessageChat() : CDCMessage(DC_MESSAGE_CHAT) {};
	/** */
	virtual ~CMessageChat() {};

	/** */
	CString sNick;
	/** */
	CString sMessage;
};

class DLL_EXPORT CMessageMyInfo : public CDCMessage {
public:
	/** */
	CMessageMyInfo() : CDCMessage(DC_MESSAGE_MYINFO) {
		lShared        = 0;
		bOperator      = FALSE;
		eAwayMode      = euamNONE;
		eClientVersion = eucvNONE;
	};
	/** */
	virtual ~CMessageMyInfo() {};

	/** */
	CString sNick;
	/** */
	CString sComment;
	/** */
	CString sUnknown;
	/** */
	CString sSpeed;
	/** */
	CString sEMail;
	/** */
	ulonglong lShared;
	/** */
	eUserAwayMode eAwayMode;
	/** */
	bool bOperator;
	/** */
	CString sVerComment;
	/** */
	eUserClientVersion eClientVersion;

	/** */
	CMessageMyInfo& operator = (const CMessageMyInfo& s)
	{
		sNick          = s.sNick;
		sComment       = s.sComment;
		sUnknown       = s.sUnknown;
		sSpeed         = s.sSpeed;
		sEMail         = s.sEMail;
		lShared        = s.lShared;
		eAwayMode      = s.eAwayMode;
		bOperator      = s.bOperator;
		sVerComment    = s.sVerComment;
		eClientVersion = s.eClientVersion;
		return *this;
	};
};

class DLL_EXPORT CMessageConnectToMe : public CDCMessage {
public:
	/** */
	CMessageConnectToMe() : CDCMessage(DC_MESSAGE_CONNECTTOME) {
		iPort = 0;
	};
	/** */
	virtual ~CMessageConnectToMe() {};

	/** */
	CString sNick;
	/** */
	CString sHost;
	/** */
	int 	iPort;
};

class DLL_EXPORT CMessageRevConnectToMe : public CDCMessage {
public:
	/** */
	CMessageRevConnectToMe() : CDCMessage(DC_MESSAGE_REVCONNECTTOME) {};
	/** */
	virtual ~CMessageRevConnectToMe() {};

	/** */
	CString sNick;
	/** */
	CString sRemoteNick;
};

class DLL_EXPORT CMessageSearch : public CDCMessage {
public:
	/** */
	CMessageSearch() : CDCMessage(DC_MESSAGE_SEARCH) {
		bLocal      = FALSE;
		iPort       = 0;
		bSizeLimit  = FALSE;
		bSizeAtMost = FALSE;
		lSize       = 0;
		eFileType   = eftUNKNOWN;
		bExtended   = FALSE;
	};
	/** */
	CMessageSearch( CMessageSearch * MessageSearch ) {
		bLocal      = MessageSearch->bLocal;
		sSource     = MessageSearch->sSource;
		iPort       = MessageSearch->iPort;
		bSizeLimit  = MessageSearch->bSizeLimit;
		bSizeAtMost = MessageSearch->bSizeAtMost;
		lSize       = MessageSearch->lSize;
		eFileType   = MessageSearch->eFileType;
		sString     = MessageSearch->sString;
		bExtended   = MessageSearch->bExtended;
	};
	/** */
	virtual ~CMessageSearch() {};

	/** local or global search */
	bool bLocal;
	/** the source, nick or host */
	CString sSource;
	/** if source a host, this is the port */
	int iPort;
	/** search options */
	bool bSizeLimit;
	/** search options */
	bool bSizeAtMost;
	/** search options */
	ulonglong lSize;
	/** search options */
	eFileTypes eFileType;
	/** search string */
	CString sString;
	/** extended protocoll */
	bool bExtended;
};

class DLL_EXPORT CMessageForceMove : public CDCMessage {
public:
	/** */
	CMessageForceMove() : CDCMessage(DC_MESSAGE_FORCEMOVE) {
		iPort = 0;
	};
	/** */
	virtual ~CMessageForceMove() {};

	/** */
	CString sHost;
	/** */
	int	iPort;
};

class DLL_EXPORT CMessageSearchResult : public CDCMessage {
public:
	/** */
	CMessageSearchResult() : CDCMessage(DC_MESSAGE_SEARCHRESULT) {
		iFreeSlot = 0;
		iMaxSlot  = 0;
	};
	/** */
	virtual ~CMessageSearchResult() {};

	/** */
	CString sNick;
	/** */
	CString sFile;
	/** */
	ulonglong lSize;
	/** */
	CString sHubName;
	/** */
	CString sHubHost;
	/** */
	unsigned int iFreeSlot;
	/** */
	unsigned int iMaxSlot;
};

class DLL_EXPORT CMessagePrivateChat : public CDCMessage {
public:
	/** */
	CMessagePrivateChat() : CDCMessage(DC_MESSAGE_PRIVATECHAT) {
		m_nEncrypted = 0;
	};
	/** */
	virtual ~CMessagePrivateChat() {};

	/** */
	CString sNick;
	/** */
	CString sFrom;
	/** */
	CString sFromNick;
	/** */
	CString sString;
	/** 0: none
	  * 1: handshake
	  * 2: crypted
	*/
	int m_nEncrypted;
};

class DLL_EXPORT CMessageHubName : public CDCMessage {
public:
	/** */
	CMessageHubName() : CDCMessage(DC_MESSAGE_HUBNAME) {};
	/** */
	virtual ~CMessageHubName() {};

	/** */
	CString sHubName;
	/** */
	CString sOldHubName;
};

// download manager object classes

class DLL_EXPORT CMessageDMFileObject : public CDCMessage {
public:
	/** */
	CMessageDMFileObject() : CDCMessage(DC_MESSAGE_FILE_OBJECT) {
		tTimeout         = 0;
		eWaitState       = etwsWAIT;
		iConnections     = 0;
		eFileState       = etfsNONE;
		lSize            = 0;
		lStartPosition   = 0;
		lCurrentPosition = 0;
		lEndPosition     = 0;
		bMulti           = FALSE;
		bRemoveFile      = FALSE;
		m_nPriority      = 0;
	};
	/** */
	CMessageDMFileObject( CMessageDMFileObject * o )
	{
		sNick            = o->sNick;
		sHubName         = o->sHubName;
		sHubHost         = o->sHubHost;
		tTimeout         = o->tTimeout;
		eWaitState       = o->eWaitState;
		iConnections     = o->iConnections;
		sRemoteFile      = o->sRemoteFile;
		sLocalFile       = o->sLocalFile;
		eFileState       = o->eFileState;
		lSize            = o->lSize;
		lStartPosition   = o->lStartPosition;
		lCurrentPosition = o->lCurrentPosition;
		lEndPosition     = o->lEndPosition;
		bMulti           = o->bMulti;
		bRemoveFile      = o->bRemoveFile;
		m_nPriority      = o->m_nPriority;
	};
	/** */
	virtual ~CMessageDMFileObject() {};

	/** */
	CString sNick;
	/** */
	CString sHubName;
	/** */
	CString sHubHost;
	/** */
	time_t tTimeout;
	/** */
	eTransferWaitState eWaitState;
	/** */
	int iConnections;

	/** remote file */
	CString sRemoteFile;
	/** the local file */
	CString sLocalFile;
	/** */
	eTransferFileState eFileState;
	/** file size */
	ulonglong lSize;
	/** current file position */
	ulonglong lStartPosition;
	/** current file position */
	ulonglong lCurrentPosition;
	/** file end position */
	ulonglong lEndPosition;
	/** */
	bool bMulti;
	/** */
	bool bRemoveFile;
	/** */
	int m_nPriority;
};

class DLL_EXPORT CMessageDMTransferObject : public CDCMessage {
public:
	/** */
	CMessageDMTransferObject() : CDCMessage(DC_MESSAGE_TRANSFER_OBJECT) {
		lSize            = 0;
		lSizeDone        = 0;
		lRate            = 0;
		lStartPosition   = 0;
		lCurrentPosition = 0;
		lEndPosition     = 0;
		eState           = estNONE;
		bRemoveTransfer  = FALSE;
	};
	/** */
	virtual ~CMessageDMTransferObject() {};

	/** */
	CString sTransferID;
	/** */
	CString sNick;
	/** */
	CString sHost;
	/** */
	CString sHubName;
	/** */
	eConnectionState eState;

	/** remote file */
	CString sRemoteFile;
	/** remote filename */
	CString sRemoteFileName;
	/** remote filename */
	CString sLocalFile;
	/** file size */
	ulonglong lSize;
	/** file size */
	ulonglong lSizeDone;
	/** file size */
	ulonglong lRate;
	/** */
	ulonglong lStartPosition;
	/** */
	ulonglong lCurrentPosition;
	/** */
	ulonglong lEndPosition;
	/** */
	bool bRemoveTransfer;
};

class DLL_EXPORT CMessageDMFileListObject : public CDCMessage {
public:
	/** */
	CMessageDMFileListObject() : CDCMessage(DC_MESSAGE_FILELIST_OBJECT) {};
	/** */
	virtual ~CMessageDMFileListObject() {};

	/** */
	CString sNick;
	/** */
	CString sHubName;
	/** */
	CString sHubHost;
	/** */
	CString sUserFileList;
};

class DLL_EXPORT CMessageDMSlotObject : public CDCMessage {
public:
	/** */
	CMessageDMSlotObject() : CDCMessage(DC_MESSAGE_SLOT_OBJECT) {
		iSlots     = 0;
		bPermanent = FALSE;
	};
	/** */
	virtual ~CMessageDMSlotObject() {};

	/** */
	CString sNick;
	/** */
	CString sHubName;
	/** */
	int iSlots;
	/** */
	bool bPermanent;
};

class DLL_EXPORT CMessageLog : public CDCMessage {
public:
	/** */
	CMessageLog() : CDCMessage(DC_MESSAGE_LOG) {};
	/** */
	virtual ~CMessageLog() {};

	/** */
	CString sMessage;
};

class DLL_EXPORT CMessageSearchUser : public CMessageNick {
public:
	/** */
	CMessageSearchUser() {
		m_eType = DC_MESSAGE_SEARCH_USER;
	};
	/** */
	virtual ~CMessageSearchUser() {};
};

class DLL_EXPORT CMessageSearchResultUser : public CMessageMyInfo {
public:
	/** */
	CMessageSearchResultUser() {
		m_eType = DC_MESSAGE_SEARCHRESULT_USER;
	};
	/** */
	virtual ~CMessageSearchResultUser() {};

	/** */
	CString m_sHubName;
};

class DLL_EXPORT CMessageSearchFile : public CMessageSearch {
public:
	/** */
	CMessageSearchFile() {
		m_eType = DC_MESSAGE_SEARCH_FILE;
	};
	/** */
	virtual ~CMessageSearchFile() {};
};

class DLL_EXPORT DCHubObject : public CObject {
public:
	/** */
	DCHubObject() {
		m_bActive = FALSE;
	}
	/** */
	DCHubObject( DCHubObject * o ) {
		m_bActive  = o->m_bActive;
		m_sHubName = o->m_sHubName;
		m_sHubHost = o->m_sHubHost;
	}

	/** */
	virtual ~DCHubObject() {};

	/** */
	bool m_bActive;
	/** */
	CString m_sHubName;
	/** */
	CString m_sHubHost;
};

class DLL_EXPORT DCMessageTraffic : public CDCMessage {
public:
	/** */
	DCMessageTraffic() : CDCMessage(DC_MESSAGE_TRAFFIC) {
		m_nRx        = 0;
		m_nTx        = 0;
		m_nDataRx    = 0;
		m_nDataTx    = 0;
		m_nControlRx = 0;
		m_nControlTx = 0;
	}
	/** */
	virtual ~DCMessageTraffic() {};

	DCMessageTraffic & operator = (const DCMessageTraffic & s)
	{
		m_nRx        = s.m_nRx;
		m_nTx        = s.m_nTx;
		m_nDataRx    = s.m_nDataRx;
		m_nDataTx    = s.m_nDataTx;
		m_nControlRx = s.m_nControlRx;
		m_nControlTx = s.m_nControlTx;

		return *this;
	};

	/** */
	ulonglong m_nRx;
	/** */
	ulonglong m_nTx;
	/** */
	ulonglong m_nDataRx;
	/** */
	ulonglong m_nDataTx;
	/** */
	ulonglong m_nControlRx;
	/** */
	ulonglong m_nControlTx;
};

#endif
